pub trait ToTelemetry {
// Required method
fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result;
}Expand description
Formats a value only through an explicitly approved telemetry representation.
Required Methods
Sourcefn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result
fn fmt_telemetry(&self, f: &mut Formatter<'_>) -> Result
Writes the representation that may leave the process boundary.
fmt keeps adapters allocation-free so high-volume telemetry paths do not
need a parallel “safe String” API just to satisfy backends like tracing.